import logging

import boto3
import botocore


def custom_input_s3_key_sensor(
    bucket_name, file_name, access_key, secret_key, session_token, **kwargs
):
    """Return True if target file present in the S3 bucket"""
    try:
        logging.debug(f"Poking {bucket_name}, {file_name}")
        s3_resource = boto3.resource(
            "s3",
            aws_access_key_id=access_key,
            aws_secret_access_key=secret_key,
            aws_session_token=session_token,
        )
        s3_resource.Object(bucket_name, file_name).get(Range="bytes=0-0")
        logging.info(f"Found [{file_name}] in {bucket_name}")
        return True
    except botocore.exceptions.ClientError as client_err:
        if client_err.response["Error"]["Code"] == "404":
            logging.error("ClientError: File does not exist")
        else:
            logging.error(f"ClientError: {str(client_err)}")
        return False
    except Exception as ex:
        logging.error(f"custom S3 sensor: Unexpected exception  {str(ex)}")
        return False
