from enum import Enum

from marshmallow import Schema, fields, validate

from . import defense


class Workflow(Schema):
    status = fields.Str(
        required=True, validate=validate.OneOf(["NEW", "REJECT", "ACCEPT"])
    )
    user_id = fields.Int(required=False)
    email = fields.Str(required=False)
    created_time = fields.Integer(required=False)
    updated_time = fields.Integer(required=False)


class Metadata(Schema):
    impact = fields.Str(validate=validate.OneOf(["HIGH", "MEDIUM", "LOW"]))
    impact_score = fields.Float()
    other_orgs_with_rule = fields.Int()  # prevalence in rule db
    impacted_device = fields.Int()  # device count
    alert_count = fields.Int()  # alert count
    application_path = fields.Str()  # For hash reputation
    application_name = fields.Str()  # For hash reputation


class RecommendationReputation(Schema):
    name = fields.Str()
    env = fields.Str()
    org_id = fields.Int()
    policy_id = fields.Int()
    rule_type = fields.Str(
        required=True, validate=validate.OneOf(["sensor_policy", "reputation_override"])
    )
    policy = fields.Nested(defense.RepRule)
    impact = fields.Nested(Metadata)
    workflow = fields.Nested(Workflow)


class RecommendationPolicy(Schema):
    name = fields.Str()
    env = fields.Str()
    org_id = fields.Int()
    policy_id = fields.Int()
    rule_type = fields.Str(
        required=True, validate=validate.OneOf(["sensor_policy", "reputation_override"])
    )
    policy = fields.Nested(defense.PemRule)
    impact = fields.Nested(Metadata)
    workflow = fields.Nested(Workflow)
