#!/usr/bin/env python
# coding: utf-8
import datetime
import os

from mycroft.common.schema.suggestion import (
    RecommendationPolicy,
    RecommendationReputation,
)
from mycroft.common.logging import get_logger

LOGLEVEL = os.environ.get("LOGLEVEL", "WARNING").upper()
logger = get_logger(LOGLEVEL)


def create_reputation_recomm_json(
    rule_type,
    env,
    org_id,
    value1,
    value2,
    other_orgs_with_rule,
    impacted_device,
    alert_count,
    r_type,
    comment2,
    impact_score,
):
    """
    :param env: env of the org
    :param org_id: org id
    :param value1:
    :param value2:
    :param other_orgs_with_rule: impact number
    :param impacted_device: impact number
    :param alert_count: impact number
    :param r_type: type of the recommendation
    :param comment2: process name for SHA256HASH
    :return:
    """
    logger.debug(
        f"rule_type: {rule_type}, env: {env}, org_id: {org_id}, value1: {value1}, value2: {value2}, other_orgs_with_rule: {other_orgs_with_rule}, impacted_device: {impacted_device}, alert_count: {alert_count}, impact_score: {impact_score}, r_type: {r_type}, comment2: {comment2}"
    )
    if r_type == "SHA256":
        value2 = comment2
    policy_dict = {
        "rule": {
            "type": r_type,
            "lastModification": "ADD",
            "lastUpdatedTime": int(datetime.datetime.utcnow().timestamp()),
            "authListType": "WHITE_LIST",
            "csrAction": False,
            "value1": value1,
            "value2": value2,
            "sourceType": "APP",
            "orgId": org_id,
            "env": env,
        }
    }
    impact_dict = {
        "other_orgs_with_rule": other_orgs_with_rule,
        "impacted_device": impacted_device,
        "alert_count": alert_count,
        "impact_score": impact_score,
    }
    work_flow_dict = {
        "status": "NEW",
    }
    reputatio_json = None
    try:
        recommendation_reputation_dict = {
            "name": "auto suggested reputation rule",
            "org_id": org_id,
            "env": env,
            "rule_type": rule_type,
            "policy": policy_dict,
            "impact": impact_dict,
            "workflow": work_flow_dict,
        }
        recommendation_reputation = RecommendationReputation().load(
            recommendation_reputation_dict
        )
        schema = RecommendationReputation()
        reputatio_json = schema.dumps(recommendation_reputation)
    except Exception as e:
        logger.error("Error in create_reputation_recomm_json. Details: %s", str(e))
    return reputatio_json


def create_perm_recomm_json(
    rule_type,
    env,
    org_id,
    policy_id,
    value1,
    value2,
    value3,
    other_orgs_with_rule,
    impacted_device,
    alert_count,
):
    """
    :param env: env of the org
    :param org_id: org id
    :param value1:
    :param value2:
    :param other_orgs_with_rule: impact number
    :param impacted_device: impact number
    :param alert_count: impact number
    :param r_type: type of the recommendation
    :return:
    """
    application_dict = {"value": value1, "type": "NAME_PATH"}
    policy_dict = {
        "rule": {"application": application_dict, "operation": value2, "action": value3}
    }
    impact_dict = {
        "other_orgs_with_rule": other_orgs_with_rule,
        "impacted_device": impacted_device,
        "alert_count": alert_count,
    }
    work_flow_dict = {
        "status": "NEW",
    }
    perm_json = None
    try:
        recommendation_perm_dict = {
            "name": "auto suggested permission rule",
            "org_id": org_id,
            "env": env,
            "policy_id": policy_id,
            "rule_type": rule_type,
            "policy": policy_dict,
            "impact": impact_dict,
            "workflow": work_flow_dict,
        }
        recommendation_perm = RecommendationPolicy().load(recommendation_perm_dict)
        schema = RecommendationPolicy()
        perm_json = schema.dumps(recommendation_perm)
    except Exception as e:
        logger.error("Error in create_perm_recomm_json. Details: %s", str(e))
    return perm_json
